@@ -1,6 +1,6 @@
 from dateutil.parser import isoparse
 
-from hcloud.core.domain import BaseDomain
+from ..core.domain import BaseDomain
 
 
 class Server(BaseDomain):
